pub struct NetpolNetworksService { /* private fields */ }Implementations
Sourceimpl NetpolNetworksService
impl NetpolNetworksService
pub fn with_operations_inspect( self, parent: &Node, name: impl AsRef<str>, ) -> Result<Self, AttachError>
pub fn with_network_registry_inspect( self, parent: &Node, name: impl AsRef<str>, ) -> Self
pub fn with_inspect( self, telemetry_parent: &Node, operations_name: impl AsRef<str>, networks_parent: &Node, networks_name: impl AsRef<str>, ) -> Result<Self, AttachError>
pub fn synthesize_reachability_snapshot(&self) -> Snapshot
pub fn set_telemetry(&mut self, telemetry: TelemetrySender)
pub fn add_stream<S: Into<NetworkRequestStream>>(&mut self, s: S)
pub async fn handle_event( &mut self, event: NetworkRequest, ) -> Result<DelegatedNetworkUpdateResult, Error>
Sourcepub fn consolidated_dns_servers(&self) -> Vec<DnsServer_>
pub fn consolidated_dns_servers(&self) -> Vec<DnsServer_>
Returns the consolidated DNS servers from the Network Registry.
Sourcepub async fn handle_network_attributes_request(
&mut self,
id: NetworksConnectionId,
req: Option<Result<NetworksRequest, Error>>,
) -> Result<(), Error>
pub async fn handle_network_attributes_request( &mut self, id: NetworksConnectionId, req: Option<Result<NetworksRequest, Error>>, ) -> Result<(), Error>
Handles a single item produced by a client’s [NetworksRequestStream].
Panics
Panics if id does not correspond to a currently registered client. A client is removed
only when its stream yields the terminal None item, and the stream is fused, so every
item from the stream belongs to a live client.
Sourcepub async fn handle_property_watcher_request(
&mut self,
id: PropertyWatcherConnectionId,
req: Option<Result<PropertyWatcherRequest, Error>>,
) -> Result<(), Error>
pub async fn handle_property_watcher_request( &mut self, id: PropertyWatcherConnectionId, req: Option<Result<PropertyWatcherRequest, Error>>, ) -> Result<(), Error>
Handles a single item produced by a client’s [PropertyWatcherRequestStream].
Panics
Panics if id does not correspond to a currently registered client. A client is removed
only when its stream yields the terminal None item, and the stream is fused, so every
item from the stream belongs to a live client.
Sourcepub async fn handle_delegated_networks_update(
&mut self,
update: Option<Result<NetworkRegistryRequest, Error>>,
) -> DelegatedNetworkUpdateResult
pub async fn handle_delegated_networks_update( &mut self, update: Option<Result<NetworkRegistryRequest, Error>>, ) -> DelegatedNetworkUpdateResult
Handles delegated network updates coming from Starnix.
Resolves network events requested through the NetworkRegistry interface, applies the
corresponding properties changes, and yields the computed DNS configuration targets for
output updates.
TODO(https://fxbug.dev/428712735): Stop returning DnsServer list once dns-resolver learns about DNS via NetworkProperties.
Panics
Panics if there is no currently active delegated networks client. A client is removed
only when its stream yields the terminal None item, and the stream is fused, so every
item from the stream belongs to a live client.
pub async fn update(&mut self, update: NetworkRegistryUpdate)