pub struct NetworkPropertiesChange {
pub added: bool,
pub marks: Option<Marks>,
pub dns_servers: Option<Vec<DnsServer_>>,
pub connectivity_state: Option<ConnectivityState>,
pub name: Option<String>,
pub network_type: Option<NetworkType>,
}Expand description
An event representing the properties that changed for a network.
Fields
added: boolWhen true, this is a new network being added. Otherwise, this is an update to an existing network.
marks: Option<Marks>The new marks for the network.
dns_servers: Option<Vec<DnsServer_>>If present, contains the new DNS servers for this network.
connectivity_state: Option<ConnectivityState>The new connectivity state of the network.
name: Option<String>The name of the network.
network_type: Option<NetworkType>The transport type of the network.