pub struct ReachabilityRequest {
pub id: ReachabilityWatcherConnectionId,
pub request: Option<Result<MonitorRequest, Error>>,
}Expand description
A wrapper for freachability::MonitorRequest that includes the
ReachabilityWatcherConnectionId and indicates whether the watcher stream is still open.
Fields
id: ReachabilityWatcherConnectionIdrequest: Option<Result<MonitorRequest, Error>>Note: Storing the Request inside the Option allows us to distinguish between the channel being closed and a Watch request being sent to support cleaner channel-closing logic.