Metric

Struct Metric 

pub struct Metric(/* private fields */);
Interface metrics.

Interface metrics are used to sort the route table. An interface with a lower metric is favored over one with a higher metric.